function Qrcode(options, id) {
	id = id || "bcid"
	options = Object.assign({
		rate: 1000, //扫描频率
		isFlash: false, //灯光是否开启
		style: {
			width:"100%",
			position: "fixed",
			height:"12rem",
			top: "0px",
			left:"0px",
			"text-align": "center",
			background: "#000",
			'z-index': "9999",
			display: "none"
		}
	}, options || {})
	this.options = options;
	this._events = {};
	this.defaultFilters = [
		plus.barcode.QR, plus.barcode.AZTEC, plus.barcode.CODE128
	];
	this.id = id;
	var bcid = document.getElementById(id)
	if(!bcid) {
		bcid = document.createElement("div");
		bcid.id = id;
		document.body.appendChild(bcid);
	}
	this.bcid = bcid;
	var cssText = [];
	Object.keys(options.style).forEach(function(key) {
		cssText.push([key, options.style[key]].join(":"));
	});
	cssText = cssText.join(";");
	bcid.style.cssText = cssText;
	var onmarked = function(data) {
		if(options.lazy) return;
		setTimeout(this.start.bind(this), options.rate, this);
	};
	this._events.marked = [onmarked];
}

Qrcode.prototype = {
	_init() {
		if(this.scanner) {
			return;
		}
		var self = this;
		var options = self.options;
		var filters = options.filters || this.defaultFilters;
		self.scanner = new plus.barcode.Barcode(this.id, filters, {
			frameColor: '#38a9fe',
			scanbarColor: '#38a9fe'
		});
		self.scanner.onmarked = function(type, code) {
			self._emit("marked", {
				type: type,
				code: code
			})
		};
		self.scanner.onerror = function(error) {
			self._emit("error", {
				error: error
			})
		};
	},
	_emit(evt, data) {
		evt += '';
		if(!this._events[evt]) return;
		var self = this;
		(function(dat) {
			setTimeout(function() {
				self._events[evt].forEach(function(ev) {
					ev.call(self, Object.assign({}, dat))
				})
			});
		})(data);
	},
	on: function(evt, func) {
		if(typeof func !== 'function') return;
		evt += "";
		this._events[evt] = this._events[evt] || [];
		this._events[evt].push(func);
	},
	off: function(evt) {
		if(this._events[evt]) {
			delete this._events[evt];
		}
	},
	_clearEvents: function() {
		var self = this;
		Object.keys(this._events).forEach(function(key) {
			delete self._events[key]
		});
	},
	start: function() {
		var self = this;
		this.bcid.style.display = "block";
		setTimeout(function() {
			if(window.plus) {
				self._init();
			} else {
				document.addEventListener("plusready", function() {
					self._init();
				}, false);
			}
			self.scanner.start({
				sound: "default"
			});
			self._emit("started");
		}, 15);
	},
	cancel: function() {
		if(!this.scanner) return;
		this.bcid.style.display = "none";
		this.scanner.cancel();
	},
	toggleFlash: function() {
		if(!this.scanner) return;
		this.scanner.setFlash(!this.options.isFlash);
		this.options.isFlash = !this.options.isFlash;
	},
	close: function() {
		if(!this.scanner) return;
		this.scanner.close();
		this.scanner.onmarked = null;
		this.scanner.onerror = null;
		this.scanner = null;
		this.options.isFlash = false;
		this.bcid.style.display = "none";
		this._emit("close");
	}
};

window.Qrcode = Qrcode;

//document.addEventListener("plusready", function() {
//	var qrcode = new Qrcode();
//	qrcode.on("marked", function(data) {
//		console.log("Success:" + JSON.stringify(data))
//	})
//	qrcode.start();
//}, false)